import { IFieldQuery } from '../interface';
import { Datasheet, Field } from '../model';
/**
 * Get information about all fields(columns) of currently view.
 * Rerendering is triggered when the fields property/columns order changes.
 *
 * If not viewId passed in, an empty array is returned.
 *
 * @param viewId The ID for view.
 * @param query Optional parameter that specifies which fieldId data to query.
 * @returns
 *
 * ### Example
 * ```js
 * import { useFields, useActiveViewId } from '@apitable/widget-sdk';
 *
 * // Show all field names
 * function FieldNames() {
 *   const viewId = useActiveViewId();
 *   const fields = useFields(viewId);
 *   return (<div>
 *     {fields.map(field => <p key={field.id}>{field.name}</p>)}
 *   </div>);
 * }
 * ```
 *
 */
export declare function useFields(viewId: string | undefined, query?: IFieldQuery): Field[];
/**
 * ## Support for loading the corresponding datasheet data fields.
 *
 * @param datasheet Datasheet instance, by {@link useDatasheet} get.
 * @param viewId The ID for view.
 * @param query Optional parameter that specifies which fieldId data to query.
 * @returns
 *
 * ### Example
 * ```js
 * import { useFields, useDatasheet } from '@apitable/widget-sdk';
 *
 * // Show all field names corresponding to the datasheetId(dstXXXXXXXX) datasheet
 * function FieldNames() {
 *   const datasheet = useDatasheet('dstXXXXXXXX');
 *   const fields = useFields(datasheet, 'vieXXXXXXX');
 *   return (<div>
 *     {fields.map(field => <p key={field.id}>{field.name}</p>)}
 *   </div>);
 * }
 * ```
 *
 */
export declare function useFields(datasheet: Datasheet | undefined, viewId: string | undefined, query?: IFieldQuery): Field[];
//# sourceMappingURL=use_fields.d.ts.map