import { ICollaCommandExecuteResult, ICollaCommandOptions, IDatasheetMap, ILabs, IMirrorMap, IOperation, IPageParams, IShareInfo, IUnitInfo, IUserInfo, IViewRow, ResourceType } from '../core';
import { WidgetLoadError } from '../initialize_widget';
import { IDatasheetClient, IDatasheetMainSimple, IExpandRecordProps, IWidgetConfigIframe, IWidgetDashboardState } from '../interface/modal';
import { IContentWindow, IInitResponse, IResponse, MouseListenerType, WidgetMessageType } from './interface';
interface IListenDatasheetMap {
    [key: string]: {
        loading?: boolean;
        subscribeViewIds?: Set<string>;
    };
}
declare class MainWidgetMessageBase {
    enable: boolean;
    /** as the window for sending messages */
    private contentWindows;
    private listenEvents;
    constructor();
    /**
     * This is a method that sends a message, if the third parameter key is passed,
     * it will only be sent to the window with the specified key, otherwise it will be broadcast to all.
     * @param type
     * @param data
     * @param key General is widgetId.
     */
    emit(type: WidgetMessageType, data: IResponse, key?: string): void;
    on(props: {
        widgetId: string;
        type: WidgetMessageType;
        callback: (data: IResponse) => void;
    }): void;
    removeListenEvent(widgetId: string, type?: WidgetMessageType): void;
    addWindow(widgetId: string, window: IContentWindow): void;
    removeWindow(widgetId: string): void;
    /**
     * Check whether the widget is in an iframe window.
     * @param widgetId
     */
    widgetInIframe(widgetId: string): boolean;
}
declare class MainWidgetMessage extends MainWidgetMessageBase {
    widgets: {
        [key: string]: {
            connected: boolean;
            listenDatasheetMap: IListenDatasheetMap;
        };
    };
    getSubscribeViewIds(datasheetId: string): string[];
    removeWindow(widgetId: string): void;
    connectWidget(widgetId: string, origin: string, callback: () => void): void;
    /**
     * Listen to widget initialization and send the initialization data required by the widget.
     * @param callback
     */
    onInitWidget(widgetId: string, callback: (res: IResponse<string>) => IInitResponse | null): void;
    /**
     * Synchronize operations to the widget when the data in the widget or datasheet changes
     * @param operations
     * @param resourceType
     * @param resourceId
     */
    syncOperations(operations: IOperation[], resourceType: ResourceType, resourceId: string): void;
    /**
     * Synchronize configuration on some widget behaviors, such as setting and expanding widget.
     * @param widgetId
     * @param config
     */
    syncWidgetConfig(widgetId: string, config: IWidgetConfigIframe): void;
    /**
     * Trigger the widget reloading.
     * @param widgetId
     */
    refreshWidget(widgetId: string): void;
    /**
     * This method is a forced refresh of the snapshot.
     * When the associated table is updated, you need to force a snapshot refresh to trigger a recalculation of visibleRows.
     * @param datasheetId
     */
    refreshSnapshot(datasheetId: string): void;
    /**
     * Listening for widget config sync from widgets.
     */
    onWidgetConfig(widgetId: string, callback: (res: IWidgetConfigIframe) => void): void;
    /**
     * Listening for cmd sync from widgets.
     */
    onSyncCmdOptions(widgetId: string, callback: (res: ICollaCommandOptions) => void): void;
    /**
     * Listening for the results of the main application application cmd sync.
     */
    syncCmdOptionsResult(widgetId: string, cmdOptionsResult: ICollaCommandExecuteResult<any>): void;
    /**
     * Synchronize client-related data in the main application datasheet.
     */
    syncClient(client: IDatasheetClient): void;
    /**
     * Synchronize userInfo-related data in the main application datasheet.
     */
    syncUnitInfo(unitInfo: IUnitInfo): void;
    /**
     * Sync main application pageParams related data synchronization.
     */
    syncPageParams(pageParams: IPageParams): void;
    /**
     * Sync main application labs related data synchronization.
     */
    syncLabs(labs: ILabs): void;
    /**
     * Sync main application share related data synchronization.
     */
    syncShare(share: IShareInfo): void;
    /**
     * Synchronizing dashboard data.
     * @param dashboard
     */
    syncDashboard(dashboard: Partial<IWidgetDashboardState>): void;
    /**
     * Sync main application mirrorMap related data synchronization.
     */
    syncMirrorMap(mirrorMap: IMirrorMap): void;
    /**
     * Listening to widget-initiated requests to load other linked table data.
     */
    onLoadOtherDatasheetInit(widgetId: string, callback: (res: string) => void): void;
    /**
     * Send to the widget after the other linked table data is loaded.
     */
    loadOtherDatasheetInit(datasheetId: string, datasheetMap: IDatasheetMap): void;
    /**
     * Other related tables update data to send to the widget.
     */
    datasheetSimpleUpdate(datasheetIds: string[], datasheetSimple: {
        [datasheetId: string]: IDatasheetMainSimple;
    }): void;
    /**
     * Listening for expand card requests from the widget.
     */
    onExpandRecord(widgetId: string, callback: (expandRecordParams: IExpandRecordProps) => void): void;
    /**
     * Mouse in and out of the widget iframe window.
     */
    onMouseListener(widgetId: string, callback: (type: MouseListenerType) => void): void;
    /**
     * Broadcast the cache updates to the widget, and send all the widgets that have dependencies.
     * In the case of a datasheet, only the cached data of the current view is updated.
     * @param cache visibleRowsBase cache.
     */
    syncCalcCache(datasheetId: string, viewId: string, cache: IViewRow[]): void;
    /**
     * Listen for cache fetches from the widget and add them to the subscription.
     */
    onInitCalcCache(widgetId: string, callback: (datasheetId: string, viewId: string) => void): void;
    /**
     * Send targeted updates to the cache of a view.
     */
    syncCalcCacheWidget(widgetId: string, datasheetId: string, viewId: string, cache: IViewRow[]): void;
    /**
     * Enter developer mode.
     */
    onExpandDevConfig(widgetId: string, callback: () => void): void;
    /**
     * Go to loading widget.
     * @param devUrl
     * @param widgetPackageId
     * @param refresh
     */
    loadWidget(widgetId: string, devUrl: string, widgetPackageId: string, refresh?: boolean): Promise<void>;
    /**
     * Listening for loading widget results.
     * @param widgetId
     * @param callback
     */
    onLoadWidget(widgetId: string, callback: (error?: WidgetLoadError) => void): void;
    /**
     * Marking cache expiration.
     * @param callback
     */
    calcExpire(datasheetId: string, viewId: string): void;
    /**
     * Synchronize data related to the main application userInfo.
     * @param userInfo
     */
    syncUserInfo(userInfo: IUserInfo): void;
}
export declare const mainWidgetMessage: MainWidgetMessage;
export {};
//# sourceMappingURL=main_widget_message.d.ts.map